@@ -151,7 +151,7 @@ function cosmotemplate(filename, addlvars)
   if (f) then
     x = f:read("*a")
     f:close()
-    fill = cosmo.fill(x, {systeminfo = deets.systeminfo, map=cosmo.map, ["if"] = cosmo.cif, v=addlvars})
+    fill = cosmo.fill(x, {systeminfo = deets.systeminfo, map=cosmo.map, inject=cosmo.inject, ["if"] = cosmo.cif, v=addlvars})
     newname = tempdir..string.sub(filename, string.find (filename, "/[^/]+$"))
     newfile = io.open(newname,"wb")
     newfile:write(fill)
