@@ -44,6 +44,8 @@
 #include <lauxlib.h>
 #include <lualib.h>
 
+#include "config.h"
+
 int audit_mode = 1;
 int rectify_mode = 0;
 int report_mode = 0;
@@ -51,7 +53,9 @@ int deptrace_mode = 0;
 int delete_tmpdir_mode = 1;
 int print_usage = 0;
 int print_version = 0;
+#ifndef HAVE_DPKG_SET_PROGNAME
 const char thisname[] = "luau";
+#endif /* HAVE_DPKG_SET_PROGNAME */
 
 static int
 dpkg_status (lua_State * L)
@@ -372,6 +376,9 @@ main (int argc, char **argv)
   fprintf (stderr, "under certain conditions.\n");
 
   push_error_context ();
+#ifdef HAVE_DPKG_SET_PROGNAME
+  dpkg_set_progname("luau");
+#endif /* HAVE_DPKG_SET_PROGNAME */
 
   modstatdb_open (msdbrw_readonly); /* Use default dpkg db directory. */
 
